==> cloud-3.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/k8s/src/Plugin/Block/K8sProjectCostsChartBlock.php <==
<?php

namespace Drupal\k8s\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\k8s\Controller\K8sProjectCostsChartController;

/**
 * Provides a block of the costs chart.
 *
 * @Block(
 *   id = "k8s_project_costs_chart",
 *   admin_label = @Translation("K8s Project Costs Chart"),
 *   category = @Translation("K8s")
 * )
 */
class K8sProjectCostsChartBlock extends K8sBaseBlock {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() ?: [] + [
      'display_k8s_project_pages_only' => 1,
      'display_cluster_in_project_pages_only' => 1,
      'chart_period' => 14,
      'cost_type' => 'ri_one_year',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    if (!$this->moduleHandler->moduleExists('cloud_budget')) {
      $module_page_link = Link::fromTextAndUrl($this->t('Cloud Budget'), Url::fromRoute('system.modules_list'))->toString();
      $this->messenger->addWarning($this->t('@link module needs to be enabled for this block.', [
        '@link' => $module_page_link,
      ]));
    }
    $controller = $this->classResolver->getInstanceFromDefinition(K8sProjectCostsChartController::class);

    $form['display_k8s_project_pages_only'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display this block in K8s Project list page and K8s Project Content page only'),
      '#default_value' => $this->configuration['display_k8s_project_pages_only'],
    ];

    $form['display_cluster_in_project_pages_only'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display K8s Cluster information in K8s Project Content page only'),
      '#default_value' => $this->configuration['display_cluster_in_project_pages_only'],
    ];

    $form['chart_period'] = [
      '#type' => 'select',
      '#title' => $this->t('Default Chart Period'),
      '#options' => $controller->getEc2ChartPeriod(),
      '#default_value' => $this->configuration['chart_period'],
    ];

    $form['cost_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Default Chart EC2 Cost Type'),
      '#options' => $controller->getEc2CostTypes(),
      '#default_value' => $this->configuration['cost_type'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $this->configuration['display_k8s_project_pages_only']
      = $form_state->getValue('display_k8s_project_pages_only');
    $this->configuration['display_cluster_in_project_pages_only']
      = $form_state->getValue('display_cluster_in_project_pages_only');
    $this->configuration['chart_period']
      = $form_state->getValue('chart_period');
    $this->configuration['cost_type']
      = $form_state->getValue('cost_type');
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    $access = parent::blockAccess($account);

    if ($access->isForbidden()) {
      return $access;
    }
    $cloud_project = $this->routeMatch->getParameter('cloud_project');
    $cloud_context = $this->routeMatch->getParameter('cloud_context');
    $cloud_projects = [];
    if (!empty($cloud_context)) {
      $cloud_projects = $this->loadEntities('cloud_project', [
        'cloud_context' => $cloud_context,
        'type' => 'k8s',
      ]);
    }
    elseif (empty($cloud_project)) {
      $cloud_projects = $this->loadEntities('cloud_project', [
        'type' => 'k8s',
      ]);
    }
    if (empty($cloud_projects)) {
      return AccessResult::forbidden();
    }
    return $access;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $route_name = $this->routeMatch->getRouteName();
    $cloud_project = $this->routeMatch->getParameter('cloud_project');
    $cloud_context = $this->routeMatch->getParameter('cloud_context');

    // If display_k8s_project_pages_only is checked, do nothing.
    if ($route_name !== 'entity.cloud_project.collection'
      && $route_name !== 'entity.cloud_project.canonical'
      && $this->configuration['display_k8s_project_pages_only']) {
      return [];
    }

    if (!$this->moduleHandler->moduleExists('cloud_budget')) {
      $module_page_link = Link::fromTextAndUrl($this->t('Cloud Budget'), Url::fromRoute('system.modules_list'))->toString();
      $this->messenger->addWarning($this->t('K8s Project Costs Chart requires @link module to be enabled.', [
        '@link' => $module_page_link,
      ]));
      return [];
    }

    $k8s_project_costs_cost_types_json_url = Url::fromRoute(
      'entity.k8s_project.cost_types',
      [
        'json' => 'json',
      ]
    )->toString();

    $k8s_project_costs_chart_periods_json_url = Url::fromRoute(
      'entity.k8s_project.all_chart_periods',
      [
        'json' => 'json',
      ]
    )->toString();

    // Use a different chart_periods endpoint
    // if cloud_context or cloud_project is present.
    if (!empty($cloud_project)) {
      $k8s_project_costs_chart_periods_json_url = Url::fromRoute(
      'entity.k8s_project.cloud_project.chart_periods',
        [
          'cloud_context' => $cloud_context,
          'cloud_project' => $cloud_project->id(),
          'json' => 'json',
        ]
      )->toString();
    }
    elseif (!empty($cloud_context)) {
      $k8s_project_costs_chart_periods_json_url = Url::fromRoute(
        'entity.k8s_project.chart_periods',
        [
          'cloud_context' => $cloud_context,
          'json' => 'json',
        ]
      )->toString();
    }

    $build = [];
    $fieldset_defs = [
      [
        'name' => 'k8s_project_costs',
        'title' => $this->t('Project Costs Chart'),
        'open' => TRUE,
        'fields' => [
          'k8s_project_costs_chart',
        ],
      ],
    ];

    $display_cluster = $this->configuration['display_cluster_in_project_pages_only'];

    if (!empty($cloud_project)) {
      $json_url = Url::fromRoute(
        'entity.k8s_project.cloud_project.costs',
        [
          'cloud_context' => $cloud_context,
          'cloud_project' => $cloud_project->id(),
        ]
      )->toString();
    }
    elseif (!empty($cloud_context)) {
      if ($display_cluster) {
        $json_url = Url::fromRoute('entity.k8s_project.costs', ['cloud_context' => $cloud_context])->toString();
      }
      else {
        $json_url = Url::fromRoute('entity.k8s_project.cluster.costs', ['cloud_context' => $cloud_context])->toString();
      }
    }
    else {
      if ($display_cluster) {
        $json_url = Url::fromRoute('entity.k8s_project.all_costs')->toString();
      }
      else {
        $json_url = Url::fromRoute('entity.k8s_project.cluster.all_costs')->toString();
      }
    }

    $build = [];

    $build['k8s_project_costs_chart'] = [
      '#markup' => '<div id="k8s_project_costs_chart"></div>',
      '#attached' => [
        'library' => [
          'k8s/k8s_project_costs_chart',
        ],
        'drupalSettings' => [
          'k8s' => [
            'k8s_project_costs_chart_json_url' => $json_url,
            'k8s_project_costs_cost_types_json_url' => $k8s_project_costs_cost_types_json_url,
            'k8s_project_costs_chart_periods_json_url' => $k8s_project_costs_chart_periods_json_url,
            'k8s_project_costs_chart_ec2_cost_type' => $this->configuration['cost_type'],
            'k8s_project_costs_chart_period' => $this->configuration['chart_period'],
          ],
        ],
      ],
    ];

    $this->cloudService->reorderForm($build, $fieldset_defs);

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    $this->killSwitch->trigger();
    // BigPipe/#cache/max-age is breaking my block javascript
    // https://www.drupal.org/forum/support/module-development-and-code-questions/2016-07-17/bigpipecachemax-age-is-breaking-my
    // "a slight delay of a second or two before the charts are built.
    // That seems to work, though it is a junky solution.".
    return $this->moduleHandler->moduleExists('big_pipe') ? 1 : 0;
  }

}

==> cloud-3.2.0.tar.gz: cloud/modules/cloud_service_providers/k8s/src/Plugin/Block/K8sProjectCostsChartBlock.php <==
<?php

namespace Drupal\k8s\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Url;
use Drupal\k8s\Controller\K8sCostsControllerBase;
use Drupal\k8s\Controller\K8sProjectCostsChartController;

/**
 * Provides a block of the costs chart.
 *
 * @Block(
 *   id = "k8s_project_costs_chart",
 *   admin_label = @Translation("K8s Project Costs Chart"),
 *   category = @Translation("K8s")
 * )
 */
class K8sProjectCostsChartBlock extends K8sBaseBlock {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return (parent::defaultConfiguration() ?: []) + [
      'display_k8s_project_pages_only' => 1,
      'display_cluster_in_project_pages_only' => 1,
      'chart_period' => 14,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $controller = $this->classResolver->getInstanceFromDefinition(K8sProjectCostsChartController::class);

    $form['display_k8s_project_pages_only'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display this block in K8s Project list page and K8s Project Content page only'),
      '#default_value' => $this->configuration['display_k8s_project_pages_only'],
    ];

    $form['display_cluster_in_project_pages_only'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display K8s Cluster information in K8s Project Content page only'),
      '#default_value' => $this->configuration['display_cluster_in_project_pages_only'],
    ];

    $form['chart_period'] = [
      '#type' => 'select',
      '#title' => $this->t('Default Chart Period'),
      '#options' => $controller->getEc2ChartPeriod(),
      '#default_value' => $this->configuration['chart_period'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $this->configuration['display_k8s_project_pages_only']
      = $form_state->getValue('display_k8s_project_pages_only');
    $this->configuration['display_cluster_in_project_pages_only']
      = $form_state->getValue('display_cluster_in_project_pages_only');
    $this->configuration['chart_period']
      = $form_state->getValue('chart_period');
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    $access = parent::blockAccess($account);

    if ($access->isForbidden()) {
      return $access;
    }
    $cloud_project = $this->routeMatch->getParameter('cloud_project');
    $cloud_context = $this->routeMatch->getParameter('cloud_context');
    $cloud_projects = [];
    if (!empty($cloud_context)) {
      $cloud_projects = $this->loadEntities('cloud_project', [
        'cloud_context' => $cloud_context,
        'type' => 'k8s',
      ]);
    }
    elseif (empty($cloud_project)) {
      $cloud_projects = $this->loadEntities('cloud_project', [
        'type' => 'k8s',
      ]);
    }
    if (empty($cloud_projects)) {
      return AccessResult::forbidden();
    }
    return $access;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $route_name = $this->routeMatch->getRouteName();
    $cloud_project = $this->routeMatch->getParameter('cloud_project');
    $cloud_context = $this->routeMatch->getParameter('cloud_context');

    // If display_k8s_project_pages_only is checked, do nothing.
    if ($route_name !== 'entity.cloud_project.collection'
      && $route_name !== 'entity.cloud_project.canonical'
      && $this->configuration['display_k8s_project_pages_only']) {
      return [];
    }

    $k8s_project_costs_cost_types_json_url = Url::fromRoute(
      'entity.k8s_project.cost_types')->toString();

    $k8s_project_costs_chart_periods_json_url = Url::fromRoute(
      'entity.k8s_project.all_chart_periods')->toString();

    // Use a different chart_periods endpoint
    // if cloud_context or cloud_project is present.
    if (!empty($cloud_project)) {
      $k8s_project_costs_chart_periods_json_url = Url::fromRoute(
      'entity.k8s_project.cloud_project.chart_periods',
        [
          'cloud_context' => $cloud_context,
          'cloud_project' => $cloud_project->id(),
        ]
      )->toString();
    }
    elseif (!empty($cloud_context)) {
      $k8s_project_costs_chart_periods_json_url = Url::fromRoute(
        'entity.k8s_project.chart_periods',
        [
          'cloud_context' => $cloud_context,
        ]
      )->toString();
    }

    $build = [];
    $fieldset_defs = [
      [
        'name' => 'k8s_project_costs',
        'title' => $this->t('Project Costs Chart'),
        'open' => TRUE,
        'fields' => [
          'k8s_project_costs_chart',
        ],
      ],
    ];

    $display_cluster = $this->configuration['display_cluster_in_project_pages_only'];

    if (!empty($cloud_project)) {
      $json_url = Url::fromRoute(
        'entity.k8s_project.cloud_project.costs',
        [
          'cloud_context' => $cloud_context,
          'cloud_project' => $cloud_project->id(),
        ]
      )->toString();
    }
    elseif (!empty($cloud_context)) {
      if ($display_cluster) {
        $json_url = Url::fromRoute('entity.k8s_project.costs', ['cloud_context' => $cloud_context])->toString();
      }
      else {
        $json_url = Url::fromRoute('entity.k8s_project.cluster.costs', ['cloud_context' => $cloud_context])->toString();
      }
    }
    else {
      if ($display_cluster) {
        $json_url = Url::fromRoute('entity.k8s_project.all_costs')->toString();
      }
      else {
        $json_url = Url::fromRoute('entity.k8s_project.cluster.all_costs')->toString();
      }
    }

    $controller = $this->classResolver->getInstanceFromDefinition(K8sCostsControllerBase::class);
    $cost_type_list = $controller->getEc2CostTypes();

    $cloud_contexts = [];
    if (!empty($cloud_project)) {
      $k8s_clusters = $cloud_project->get('field_k8s_clusters')->getValue();
      foreach ($k8s_clusters ?: [] as $k8s_cluster) {
        $cloud_contexts[] = $k8s_cluster['value'];
      }
    }
    elseif (!empty($cloud_context)) {
      $cloud_contexts[] = $cloud_context;
    }

    $default_cost_type = $this->getDefaultCostType($cloud_contexts);

    $cost_type = array_key_exists($default_cost_type, $cost_type_list)
      ? $default_cost_type
      : self::DEFAULT_COST_TYPE;

    $build['k8s_project_costs_chart'] = [
      '#markup' => '<div id="k8s_project_costs_chart"></div>',
      '#attached' => [
        'library' => [
          'k8s/k8s_project_costs_chart',
        ],
        'drupalSettings' => [
          'k8s' => [
            'k8s_project_costs_chart_json_url' => $json_url,
            'k8s_project_costs_cost_types_json_url' => $k8s_project_costs_cost_types_json_url,
            'k8s_project_costs_chart_periods_json_url' => $k8s_project_costs_chart_periods_json_url,
            'k8s_project_costs_chart_ec2_cost_type' => $cost_type,
            'k8s_project_costs_chart_period' => $this->configuration['chart_period'],
          ],
        ],
      ],
    ];

    $this->cloudService->reorderForm($build, $fieldset_defs);

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    $this->killSwitch->trigger();
    // BigPipe/#cache/max-age is breaking my block javascript
    // https://www.drupal.org/forum/support/module-development-and-code-questions/2016-07-17/bigpipecachemax-age-is-breaking-my
    // "a slight delay of a second or two before the charts are built.
    // That seems to work, though it is a junky solution.".
    return $this->moduleHandler->moduleExists('big_pipe') ? 1 : 0;
  }

}
